package com.apicloud.arcfacepublic.camera;

import android.graphics.Point;
import android.graphics.SurfaceTexture;
import android.hardware.Camera;
import android.util.Log;
import android.view.SurfaceHolder;
import android.view.SurfaceView;
import android.view.TextureView;
import android.view.View;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Comparator;
import java.util.List;

public class DualCameraHelper implements Camera.PreviewCallback {
    private static final String TAG = "CameraHelper";
    private static List<Camera.Size> irSupportedPreviewSizes;
    private static List<Camera.Size> rgbSupportedPreviewSizes;
    private int additionalRotation;
    private CameraListener cameraListener;
    private int displayOrientation;
    private boolean isMirror;
    private Camera mCamera;
    private int mCameraId;
    private View previewDisplayView;
    private Camera.Size previewSize;
    private Point previewViewSize;
    private int rotation;
    private Integer specificCameraId;
    private Point specificPreviewSize;
    private SurfaceHolder.Callback surfaceCallback;
    private TextureView.SurfaceTextureListener textureListener;

    private DualCameraHelper(Builder builder) {
        this.displayOrientation = 0;
        this.isMirror = false;
        this.specificCameraId = null;
        this.textureListener = new TextureView.SurfaceTextureListener() {
            /* class com.apicloud.arcfacepublic.camera.DualCameraHelper.AnonymousClass2 */

            public void onSurfaceTextureUpdated(SurfaceTexture surfaceTexture) {
            }

            public void onSurfaceTextureAvailable(SurfaceTexture surfaceTexture, int i, int i2) {
                if (DualCameraHelper.this.mCamera != null) {
                    try {
                        DualCameraHelper.this.mCamera.setPreviewTexture(surfaceTexture);
                    } catch (IOException e) {
                        e.printStackTrace();
                    }
                }
            }

            public void onSurfaceTextureSizeChanged(SurfaceTexture surfaceTexture, int i, int i2) {
                Log.i(DualCameraHelper.TAG, "onSurfaceTextureSizeChanged: " + i + "  " + i2);
            }

            public boolean onSurfaceTextureDestroyed(SurfaceTexture surfaceTexture) {
                DualCameraHelper.this.stop();
                return false;
            }
        };
        this.surfaceCallback = new SurfaceHolder.Callback() {
            /* class com.apicloud.arcfacepublic.camera.DualCameraHelper.AnonymousClass3 */

            public void surfaceChanged(SurfaceHolder surfaceHolder, int i, int i2, int i3) {
            }

            public void surfaceCreated(SurfaceHolder surfaceHolder) {
                if (DualCameraHelper.this.mCamera != null) {
                    try {
                        DualCameraHelper.this.mCamera.setPreviewDisplay(surfaceHolder);
                    } catch (IOException e) {
                        e.printStackTrace();
                    }
                }
            }

            public void surfaceDestroyed(SurfaceHolder surfaceHolder) {
                DualCameraHelper.this.stop();
            }
        };
        this.previewDisplayView = builder.previewDisplayView;
        this.specificCameraId = builder.specificCameraId;
        this.cameraListener = builder.cameraListener;
        this.rotation = builder.rotation;
        this.additionalRotation = builder.additionalRotation;
        this.previewViewSize = builder.previewViewSize;
        this.specificPreviewSize = builder.previewSize;
        if (builder.previewDisplayView instanceof TextureView) {
            this.isMirror = builder.isMirror;
        } else if (this.isMirror) {
            throw new RuntimeException("mirror is effective only when the preview is on a textureView");
        }
    }

    public void init() {
        View view = this.previewDisplayView;
        if (view instanceof TextureView) {
            ((TextureView) view).setSurfaceTextureListener(this.textureListener);
        } else if (view instanceof SurfaceView) {
            ((SurfaceView) view).getHolder().addCallback(this.surfaceCallback);
        }
        if (this.isMirror) {
            this.previewDisplayView.setScaleX(-1.0f);
        }
    }

    private List<Camera.Size> getCommonSupportedPreviewSize() {
        if (irSupportedPreviewSizes == null) {
            Camera open = Camera.open(1);
            irSupportedPreviewSizes = open.getParameters().getSupportedPreviewSizes();
            open.release();
        }
        if (rgbSupportedPreviewSizes == null) {
            Camera open2 = Camera.open(0);
            rgbSupportedPreviewSizes = open2.getParameters().getSupportedPreviewSizes();
            open2.release();
        }
        ArrayList arrayList = new ArrayList();
        for (Camera.Size size : rgbSupportedPreviewSizes) {
            for (Camera.Size size2 : irSupportedPreviewSizes) {
                if (size2.width == size.width && size2.height == size.height) {
                    arrayList.add(size);
                }
            }
        }
        return arrayList;
    }

    public void start() {
        synchronized (this) {
            if (this.mCamera == null) {
                List<Camera.Size> commonSupportedPreviewSize = getCommonSupportedPreviewSize();
                this.mCameraId = Camera.getNumberOfCameras() - 1;
                if (this.specificCameraId != null && this.specificCameraId.intValue() <= this.mCameraId) {
                    this.mCameraId = this.specificCameraId.intValue();
                }
                if (this.mCameraId == -1) {
                    if (this.cameraListener != null) {
                        this.cameraListener.onCameraError(new Exception("camera not found"));
                    }
                    return;
                }
                if (this.mCamera == null) {
                    this.mCamera = Camera.open(this.mCameraId);
                }
                int cameraOri = getCameraOri(this.rotation);
                this.displayOrientation = cameraOri;
                this.mCamera.setDisplayOrientation(cameraOri);
                try {
                    Camera.Parameters parameters = this.mCamera.getParameters();
                    parameters.setPreviewFormat(17);
                    this.previewSize = parameters.getPreviewSize();
                    if (commonSupportedPreviewSize != null && commonSupportedPreviewSize.size() > 0) {
                        this.previewSize = getBestSupportedSize(commonSupportedPreviewSize, this.previewViewSize);
                    }
                    parameters.setPreviewSize(this.previewSize.width, this.previewSize.height);
                    List<String> supportedFocusModes = parameters.getSupportedFocusModes();
                    if (supportedFocusModes != null && supportedFocusModes.size() > 0) {
                        if (supportedFocusModes.contains("continuous-picture")) {
                            parameters.setFocusMode("continuous-picture");
                        } else if (supportedFocusModes.contains("continuous-video")) {
                            parameters.setFocusMode("continuous-video");
                        } else if (supportedFocusModes.contains("auto")) {
                            parameters.setFocusMode("auto");
                        }
                    }
                    this.mCamera.setParameters(parameters);
                    if (this.previewDisplayView instanceof TextureView) {
                        this.mCamera.setPreviewTexture(((TextureView) this.previewDisplayView).getSurfaceTexture());
                    } else {
                        this.mCamera.setPreviewDisplay(((SurfaceView) this.previewDisplayView).getHolder());
                    }
                    this.mCamera.setPreviewCallback(this);
                    this.mCamera.startPreview();
                    if (this.cameraListener != null) {
                        this.cameraListener.onCameraOpened(this.mCamera, this.mCameraId, this.displayOrientation, this.isMirror);
                    }
                } catch (Exception e) {
                    if (this.cameraListener != null) {
                        this.cameraListener.onCameraError(e);
                    }
                }
            }
        }
    }

    private int getCameraOri(int i) {
        int i2 = i * 90;
        if (i == 0) {
            i2 = 0;
        } else if (i == 1) {
            i2 = 90;
        } else if (i == 2) {
            i2 = 180;
        } else if (i == 3) {
            i2 = 270;
        }
        int i3 = this.additionalRotation / 90;
        this.additionalRotation = i3;
        int i4 = i3 * 90;
        this.additionalRotation = i4;
        int i5 = i2 + i4;
        Camera.CameraInfo cameraInfo = new Camera.CameraInfo();
        Camera.getCameraInfo(this.mCameraId, cameraInfo);
        if (cameraInfo.facing == 1) {
            return (360 - ((cameraInfo.orientation + i5) % 360)) % 360;
        }
        return ((cameraInfo.orientation - i5) + 360) % 360;
    }

    public void stop() {
        synchronized (this) {
            if (this.mCamera != null) {
                this.mCamera.setPreviewCallback(null);
                this.mCamera.stopPreview();
                this.mCamera.release();
                this.mCamera = null;
                if (this.cameraListener != null) {
                    this.cameraListener.onCameraClosed();
                }
            }
        }
    }

    public boolean isStopped() {
        boolean z;
        synchronized (this) {
            z = this.mCamera == null;
        }
        return z;
    }

    public void release() {
        synchronized (this) {
            stop();
            this.previewDisplayView = null;
            this.specificCameraId = null;
            this.cameraListener = null;
            this.previewViewSize = null;
            this.specificPreviewSize = null;
            this.previewSize = null;
        }
    }

    private Camera.Size getBestSupportedSize(List<Camera.Size> list, Point point) {
        float f;
        if (list == null || list.size() == 0) {
            return this.mCamera.getParameters().getPreviewSize();
        }
        boolean z = false;
        Camera.Size[] sizeArr = (Camera.Size[]) list.toArray(new Camera.Size[0]);
        Arrays.sort(sizeArr, new Comparator<Camera.Size>() {
            /* class com.apicloud.arcfacepublic.camera.DualCameraHelper.AnonymousClass1 */

            public int compare(Camera.Size size, Camera.Size size2) {
                if (size.width > size2.width) {
                    return -1;
                }
                if (size.width != size2.width || size.height <= size2.height) {
                    return 1;
                }
                return -1;
            }
        });
        List<Camera.Size> asList = Arrays.asList(sizeArr);
        Camera.Size size = (Camera.Size) asList.get(0);
        if (point != null) {
            f = ((float) point.x) / ((float) point.y);
        } else {
            f = ((float) size.width) / ((float) size.height);
        }
        if (f > 1.0f) {
            f = 1.0f / f;
        }
        if (this.additionalRotation % 180 == 0) {
            z = true;
        }
        for (Camera.Size size2 : asList) {
            if (size2.width >= 720 && size2.height >= 720) {
                Point point2 = this.specificPreviewSize;
                if (point2 != null && point2.x == size2.width && this.specificPreviewSize.y == size2.height) {
                    return size2;
                }
                if (z) {
                    if (Math.abs((((float) size2.height) / ((float) size2.width)) - f) >= Math.abs((((float) size.height) / ((float) size.width)) - f)) {
                    }
                } else if (Math.abs((((float) size2.width) / ((float) size2.height)) - f) >= Math.abs((((float) size.width) / ((float) size.height)) - f)) {
                }
                size = size2;
            }
        }
        return size;
    }

    public List<Camera.Size> getSupportedPreviewSizes() {
        Camera camera = this.mCamera;
        if (camera == null) {
            return null;
        }
        return camera.getParameters().getSupportedPreviewSizes();
    }

    public List<Camera.Size> getSupportedPictureSizes() {
        Camera camera = this.mCamera;
        if (camera == null) {
            return null;
        }
        return camera.getParameters().getSupportedPictureSizes();
    }

    public void onPreviewFrame(byte[] bArr, Camera camera) {
        CameraListener cameraListener2 = this.cameraListener;
        if (cameraListener2 != null) {
            cameraListener2.onPreview(bArr, camera);
        }
    }

    public void changeDisplayOrientation(int i) {
        if (this.mCamera != null) {
            this.rotation = i;
            int cameraOri = getCameraOri(i);
            this.displayOrientation = cameraOri;
            this.mCamera.setDisplayOrientation(cameraOri);
            CameraListener cameraListener2 = this.cameraListener;
            if (cameraListener2 != null) {
                cameraListener2.onCameraConfigurationChanged(this.mCameraId, this.displayOrientation);
            }
        }
    }

    public static final class Builder {
        private int additionalRotation;
        private CameraListener cameraListener;
        private boolean isMirror;
        private View previewDisplayView;
        private Point previewSize;
        private Point previewViewSize;
        private int rotation;
        private Integer specificCameraId;

        public Builder previewOn(View view) {
            if ((view instanceof SurfaceView) || (view instanceof TextureView)) {
                this.previewDisplayView = view;
                return this;
            }
            throw new RuntimeException("you must preview on a textureView or a surfaceView");
        }

        public Builder isMirror(boolean z) {
            this.isMirror = z;
            return this;
        }

        public Builder previewSize(Point point) {
            this.previewSize = point;
            return this;
        }

        public Builder previewViewSize(Point point) {
            this.previewViewSize = point;
            return this;
        }

        public Builder rotation(int i) {
            this.rotation = i;
            return this;
        }

        public Builder additionalRotation(int i) {
            this.additionalRotation = i;
            return this;
        }

        public Builder specificCameraId(Integer num) {
            this.specificCameraId = num;
            return this;
        }

        public Builder cameraListener(CameraListener cameraListener2) {
            this.cameraListener = cameraListener2;
            return this;
        }

        public DualCameraHelper build() {
            if (this.previewViewSize == null) {
                Log.e(DualCameraHelper.TAG, "previewViewSize is null, now use default previewSize");
            }
            if (this.cameraListener == null) {
                Log.e(DualCameraHelper.TAG, "cameraListener is null, callback will not be called");
            }
            if (this.previewDisplayView != null) {
                return new DualCameraHelper(this);
            }
            throw new RuntimeException("you must preview on a textureView or a surfaceView");
        }
    }
}
