package com.google.zxing.oned;

import com.google.zxing.BarcodeFormat;
import com.google.zxing.ChecksumException;
import com.google.zxing.DecodeHintType;
import com.google.zxing.FormatException;
import com.google.zxing.NotFoundException;
import com.google.zxing.Result;
import com.google.zxing.ResultPoint;
import com.google.zxing.common.BitArray;
import java.util.ArrayList;
import java.util.Map;

public final class Code128Reader extends OneDReader {
    private static final int CODE_CODE_A = 101;
    private static final int CODE_CODE_B = 100;
    private static final int CODE_CODE_C = 99;
    private static final int CODE_FNC_1 = 102;
    private static final int CODE_FNC_2 = 97;
    private static final int CODE_FNC_3 = 96;
    private static final int CODE_FNC_4_A = 101;
    private static final int CODE_FNC_4_B = 100;
    static final int[][] CODE_PATTERNS = {new int[]{2, 1, 2, 2, 2, 2}, new int[]{2, 2, 2, 1, 2, 2}, new int[]{2, 2, 2, 2, 2, 1}, new int[]{1, 2, 1, 2, 2, 3}, new int[]{1, 2, 1, 3, 2, 2}, new int[]{1, 3, 1, 2, 2, 2}, new int[]{1, 2, 2, 2, 1, 3}, new int[]{1, 2, 2, 3, 1, 2}, new int[]{1, 3, 2, 2, 1, 2}, new int[]{2, 2, 1, 2, 1, 3}, new int[]{2, 2, 1, 3, 1, 2}, new int[]{2, 3, 1, 2, 1, 2}, new int[]{1, 1, 2, 2, 3, 2}, new int[]{1, 2, 2, 1, 3, 2}, new int[]{1, 2, 2, 2, 3, 1}, new int[]{1, 1, 3, 2, 2, 2}, new int[]{1, 2, 3, 1, 2, 2}, new int[]{1, 2, 3, 2, 2, 1}, new int[]{2, 2, 3, 2, 1, 1}, new int[]{2, 2, 1, 1, 3, 2}, new int[]{2, 2, 1, 2, 3, 1}, new int[]{2, 1, 3, 2, 1, 2}, new int[]{2, 2, 3, 1, 1, 2}, new int[]{3, 1, 2, 1, 3, 1}, new int[]{3, 1, 1, 2, 2, 2}, new int[]{3, 2, 1, 1, 2, 2}, new int[]{3, 2, 1, 2, 2, 1}, new int[]{3, 1, 2, 2, 1, 2}, new int[]{3, 2, 2, 1, 1, 2}, new int[]{3, 2, 2, 2, 1, 1}, new int[]{2, 1, 2, 1, 2, 3}, new int[]{2, 1, 2, 3, 2, 1}, new int[]{2, 3, 2, 1, 2, 1}, new int[]{1, 1, 1, 3, 2, 3}, new int[]{1, 3, 1, 1, 2, 3}, new int[]{1, 3, 1, 3, 2, 1}, new int[]{1, 1, 2, 3, 1, 3}, new int[]{1, 3, 2, 1, 1, 3}, new int[]{1, 3, 2, 3, 1, 1}, new int[]{2, 1, 1, 3, 1, 3}, new int[]{2, 3, 1, 1, 1, 3}, new int[]{2, 3, 1, 3, 1, 1}, new int[]{1, 1, 2, 1, 3, 3}, new int[]{1, 1, 2, 3, 3, 1}, new int[]{1, 3, 2, 1, 3, 1}, new int[]{1, 1, 3, 1, 2, 3}, new int[]{1, 1, 3, 3, 2, 1}, new int[]{1, 3, 3, 1, 2, 1}, new int[]{3, 1, 3, 1, 2, 1}, new int[]{2, 1, 1, 3, 3, 1}, new int[]{2, 3, 1, 1, 3, 1}, new int[]{2, 1, 3, 1, 1, 3}, new int[]{2, 1, 3, 3, 1, 1}, new int[]{2, 1, 3, 1, 3, 1}, new int[]{3, 1, 1, 1, 2, 3}, new int[]{3, 1, 1, 3, 2, 1}, new int[]{3, 3, 1, 1, 2, 1}, new int[]{3, 1, 2, 1, 1, 3}, new int[]{3, 1, 2, 3, 1, 1}, new int[]{3, 3, 2, 1, 1, 1}, new int[]{3, 1, 4, 1, 1, 1}, new int[]{2, 2, 1, 4, 1, 1}, new int[]{4, 3, 1, 1, 1, 1}, new int[]{1, 1, 1, 2, 2, 4}, new int[]{1, 1, 1, 4, 2, 2}, new int[]{1, 2, 1, 1, 2, 4}, new int[]{1, 2, 1, 4, 2, 1}, new int[]{1, 4, 1, 1, 2, 2}, new int[]{1, 4, 1, 2, 2, 1}, new int[]{1, 1, 2, 2, 1, 4}, new int[]{1, 1, 2, 4, 1, 2}, new int[]{1, 2, 2, 1, 1, 4}, new int[]{1, 2, 2, 4, 1, 1}, new int[]{1, 4, 2, 1, 1, 2}, new int[]{1, 4, 2, 2, 1, 1}, new int[]{2, 4, 1, 2, 1, 1}, new int[]{2, 2, 1, 1, 1, 4}, new int[]{4, 1, 3, 1, 1, 1}, new int[]{2, 4, 1, 1, 1, 2}, new int[]{1, 3, 4, 1, 1, 1}, new int[]{1, 1, 1, 2, 4, 2}, new int[]{1, 2, 1, 1, 4, 2}, new int[]{1, 2, 1, 2, 4, 1}, new int[]{1, 1, 4, 2, 1, 2}, new int[]{1, 2, 4, 1, 1, 2}, new int[]{1, 2, 4, 2, 1, 1}, new int[]{4, 1, 1, 2, 1, 2}, new int[]{4, 2, 1, 1, 1, 2}, new int[]{4, 2, 1, 2, 1, 1}, new int[]{2, 1, 2, 1, 4, 1}, new int[]{2, 1, 4, 1, 2, 1}, new int[]{4, 1, 2, 1, 2, 1}, new int[]{1, 1, 1, 1, 4, 3}, new int[]{1, 1, 1, 3, 4, 1}, new int[]{1, 3, 1, 1, 4, 1}, new int[]{1, 1, 4, 1, 1, 3}, new int[]{1, 1, 4, 3, 1, 1}, new int[]{4, 1, 1, 1, 1, 3}, new int[]{4, 1, 1, 3, 1, 1}, new int[]{1, 1, 3, 1, 4, 1}, new int[]{1, 1, 4, 1, 3, 1}, new int[]{3, 1, 1, 1, 4, 1}, new int[]{4, 1, 1, 1, 3, 1}, new int[]{2, 1, 1, 4, 1, 2}, new int[]{2, 1, 1, 2, 1, 4}, new int[]{2, 1, 1, 2, 3, 2}, new int[]{2, 3, 3, 1, 1, 1, 2}};
    private static final int CODE_SHIFT = 98;
    private static final int CODE_START_A = 103;
    private static final int CODE_START_B = 104;
    private static final int CODE_START_C = 105;
    private static final int CODE_STOP = 106;
    private static final float MAX_AVG_VARIANCE = 0.25f;
    private static final float MAX_INDIVIDUAL_VARIANCE = 0.7f;

    private static int[] findStartPattern(BitArray bitArray) throws NotFoundException {
        int size = bitArray.getSize();
        int nextSet = bitArray.getNextSet(0);
        int[] iArr = new int[6];
        int i = nextSet;
        boolean z = false;
        int i2 = 0;
        while (nextSet < size) {
            if (bitArray.get(nextSet) ^ z) {
                iArr[i2] = iArr[i2] + 1;
            } else {
                if (i2 == 5) {
                    float f = MAX_AVG_VARIANCE;
                    int i3 = -1;
                    for (int i4 = CODE_START_A; i4 <= CODE_START_C; i4++) {
                        float patternMatchVariance = patternMatchVariance(iArr, CODE_PATTERNS[i4], MAX_INDIVIDUAL_VARIANCE);
                        if (patternMatchVariance < f) {
                            i3 = i4;
                            f = patternMatchVariance;
                        }
                    }
                    if (i3 < 0 || !bitArray.isRange(Math.max(0, i - ((nextSet - i) / 2)), i, false)) {
                        i += iArr[0] + iArr[1];
                        System.arraycopy(iArr, 2, iArr, 0, 4);
                        iArr[4] = 0;
                        iArr[5] = 0;
                        i2--;
                    } else {
                        return new int[]{i, nextSet, i3};
                    }
                } else {
                    i2++;
                }
                iArr[i2] = 1;
                z = !z;
            }
            nextSet++;
        }
        throw NotFoundException.getNotFoundInstance();
    }

    private static int decodeCode(BitArray bitArray, int[] iArr, int i) throws NotFoundException {
        recordPattern(bitArray, i, iArr);
        float f = MAX_AVG_VARIANCE;
        int i2 = -1;
        int i3 = 0;
        while (true) {
            int[][] iArr2 = CODE_PATTERNS;
            if (i3 >= iArr2.length) {
                break;
            }
            float patternMatchVariance = patternMatchVariance(iArr, iArr2[i3], MAX_INDIVIDUAL_VARIANCE);
            if (patternMatchVariance < f) {
                i2 = i3;
                f = patternMatchVariance;
            }
            i3++;
        }
        if (i2 >= 0) {
            return i2;
        }
        throw NotFoundException.getNotFoundInstance();
    }

    /* JADX DEBUG: Multi-variable search result rejected for r29v0, resolved type: com.google.zxing.common.BitArray */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r3v0 */
    /* JADX WARN: Type inference failed for: r3v1, types: [boolean] */
    /* JADX WARN: Type inference failed for: r3v4 */
    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    /* JADX WARNING: Code restructure failed: missing block: B:73:0x017a, code lost:
        if (r15 != false) goto L_0x01e0;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:97:0x01de, code lost:
        if (r15 != false) goto L_0x01e0;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:98:0x01e0, code lost:
        r2 = false;
        r22 = false;
        r23 = false;
     */
    /* JADX WARNING: Removed duplicated region for block: B:100:0x01f2 A[PHI: r9 r15 r21 
      PHI: (r9v13 boolean) = (r9v16 boolean), (r9v17 boolean) binds: [B:86:0x01b3, B:64:0x0159] A[DONT_GENERATE, DONT_INLINE]
      PHI: (r15v11 boolean) = (r15v12 boolean), (r15v14 boolean) binds: [B:86:0x01b3, B:64:0x0159] A[DONT_GENERATE, DONT_INLINE]
      PHI: (r21v11 boolean) = (r21v15 boolean), (r21v17 boolean) binds: [B:86:0x01b3, B:64:0x0159] A[DONT_GENERATE, DONT_INLINE]] */
    /* JADX WARNING: Removed duplicated region for block: B:104:0x0207 A[PHI: r9 r15 r16 r21 
      PHI: (r9v11 boolean) = (r9v12 boolean), (r9v16 boolean), (r9v16 boolean), (r9v16 boolean), (r9v16 boolean), (r9v17 boolean), (r9v17 boolean), (r9v17 boolean), (r9v17 boolean) binds: [B:103:0x0205, B:86:0x01b3, B:87:0x01b7, B:91:0x01c3, B:90:0x01bf, B:64:0x0159, B:65:0x015e, B:69:0x016b, B:68:0x0166] A[DONT_GENERATE, DONT_INLINE]
      PHI: (r15v9 boolean) = (r15v10 boolean), (r15v12 boolean), (r15v12 boolean), (r15v12 boolean), (r15v12 boolean), (r15v14 boolean), (r15v14 boolean), (r15v14 boolean), (r15v14 boolean) binds: [B:103:0x0205, B:86:0x01b3, B:87:0x01b7, B:91:0x01c3, B:90:0x01bf, B:64:0x0159, B:65:0x015e, B:69:0x016b, B:68:0x0166] A[DONT_GENERATE, DONT_INLINE]
      PHI: (r16v4 boolean) = (r16v5 boolean), (r16v1 boolean), (r16v1 boolean), (r16v1 boolean), (r16v1 boolean), (r16v1 boolean), (r16v1 boolean), (r16v1 boolean), (r16v1 boolean) binds: [B:103:0x0205, B:86:0x01b3, B:87:0x01b7, B:91:0x01c3, B:90:0x01bf, B:64:0x0159, B:65:0x015e, B:69:0x016b, B:68:0x0166] A[DONT_GENERATE, DONT_INLINE]
      PHI: (r21v9 boolean) = (r21v10 boolean), (r21v15 boolean), (r21v15 boolean), (r21v15 boolean), (r21v15 boolean), (r21v17 boolean), (r21v17 boolean), (r21v17 boolean), (r21v17 boolean) binds: [B:103:0x0205, B:86:0x01b3, B:87:0x01b7, B:91:0x01c3, B:90:0x01bf, B:64:0x0159, B:65:0x015e, B:69:0x016b, B:68:0x0166] A[DONT_GENERATE, DONT_INLINE]] */
    /* JADX WARNING: Unknown variable types count: 1 */
    @Override // com.google.zxing.oned.OneDReader
    public Result decodeRow(int i, BitArray bitArray, Map<DecodeHintType, ?> map) throws NotFoundException, FormatException, ChecksumException {
        char c;
        boolean z;
        boolean z2;
        boolean z3;
        boolean z4;
        boolean z5;
        char c2 = 1;
        ?? r3 = 0;
        boolean z6 = map != null && map.containsKey(DecodeHintType.ASSUME_GS1);
        int[] findStartPattern = findStartPattern(bitArray);
        int i2 = 2;
        int i3 = findStartPattern[2];
        ArrayList arrayList = new ArrayList(20);
        arrayList.add(Byte.valueOf((byte) i3));
        char c3 = 'c';
        switch (i3) {
            case CODE_START_A /*{ENCODED_INT: 103}*/:
                c = 'e';
                break;
            case CODE_START_B /*{ENCODED_INT: 104}*/:
                c = 'd';
                break;
            case CODE_START_C /*{ENCODED_INT: 105}*/:
                c = 'c';
                break;
            default:
                throw FormatException.getFormatInstance();
        }
        StringBuilder sb = new StringBuilder(20);
        char c4 = 6;
        int[] iArr = new int[6];
        int i4 = 0;
        boolean z7 = false;
        boolean z8 = false;
        int i5 = 0;
        int i6 = 0;
        boolean z9 = true;
        boolean z10 = false;
        boolean z11 = false;
        int i7 = findStartPattern[0];
        int i8 = findStartPattern[1];
        char c5 = c;
        while (!z7) {
            int decodeCode = decodeCode(bitArray, iArr, i8);
            arrayList.add(Byte.valueOf((byte) decodeCode));
            if (decodeCode != CODE_STOP) {
                z9 = true;
            }
            if (decodeCode != CODE_STOP) {
                i6++;
                i3 += i6 * decodeCode;
            }
            int i9 = i8;
            char c6 = r3;
            while (c6 < c4) {
                i9 += iArr[c6 == 1 ? 1 : 0];
                z10 = z10;
                c4 = 6;
                c6 = (c6 == 1 ? 1 : 0) + 1;
            }
            switch (decodeCode) {
                case CODE_START_A /*{ENCODED_INT: 103}*/:
                case CODE_START_B /*{ENCODED_INT: 104}*/:
                case CODE_START_C /*{ENCODED_INT: 105}*/:
                    throw FormatException.getFormatInstance();
                default:
                    switch (c5) {
                        case 'c':
                            z2 = z10;
                            z3 = z11;
                            if (decodeCode >= 100) {
                                if (decodeCode != CODE_STOP) {
                                    z9 = false;
                                }
                                if (decodeCode != CODE_STOP) {
                                    switch (decodeCode) {
                                        case 100:
                                            z11 = z3;
                                            z10 = z2;
                                            z = false;
                                            c5 = 'd';
                                            break;
                                        case 101:
                                            z11 = z3;
                                            z10 = z2;
                                            z = false;
                                            c5 = 'e';
                                            break;
                                        case CODE_FNC_1 /*{ENCODED_INT: 102}*/:
                                            if (z6) {
                                                if (sb.length() == 0) {
                                                    sb.append("]C1");
                                                } else {
                                                    sb.append((char) 29);
                                                }
                                            }
                                        default:
                                            z11 = z3;
                                            z10 = z2;
                                            z = false;
                                            break;
                                    }
                                } else {
                                    z11 = z3;
                                    z10 = z2;
                                    z = false;
                                    z7 = true;
                                    break;
                                }
                            } else {
                                if (decodeCode < 10) {
                                    sb.append('0');
                                }
                                sb.append(decodeCode);
                            }
                            z11 = z3;
                            z10 = z2;
                            z = false;
                        case 'd':
                            z4 = z10;
                            z5 = z11;
                            if (decodeCode < CODE_FNC_3) {
                                if (z4 == z5) {
                                    sb.append((char) (decodeCode + 32));
                                } else {
                                    sb.append((char) (decodeCode + 32 + 128));
                                }
                                z11 = z5;
                                z = false;
                                z10 = false;
                                break;
                            } else {
                                if (decodeCode != CODE_STOP) {
                                    z9 = false;
                                }
                                if (decodeCode != CODE_STOP) {
                                    switch (decodeCode) {
                                        case CODE_FNC_3 /*{ENCODED_INT: 96}*/:
                                        case CODE_FNC_2 /*{ENCODED_INT: 97}*/:
                                        default:
                                            z11 = z5;
                                            z10 = z4;
                                            z = false;
                                            break;
                                        case CODE_SHIFT /*{ENCODED_INT: 98}*/:
                                            z11 = z5;
                                            z10 = z4;
                                            z = true;
                                            c5 = 'e';
                                            break;
                                        case 99:
                                            z11 = z5;
                                            z10 = z4;
                                            z = false;
                                            c5 = 'c';
                                            break;
                                        case 100:
                                            if (z5 || !z4) {
                                                if (z5) {
                                                }
                                                z11 = z5;
                                                z = false;
                                                z10 = true;
                                                break;
                                            }
                                            z = false;
                                            z10 = false;
                                            z11 = true;
                                            break;
                                        case 101:
                                            z11 = z5;
                                            z10 = z4;
                                            z = false;
                                            c5 = 'e';
                                            break;
                                        case CODE_FNC_1 /*{ENCODED_INT: 102}*/:
                                            if (z6) {
                                                if (sb.length() == 0) {
                                                    sb.append("]C1");
                                                } else {
                                                    sb.append((char) 29);
                                                }
                                            }
                                            z11 = z5;
                                            z10 = z4;
                                            z = false;
                                            break;
                                    }
                                }
                                z7 = true;
                                z11 = z5;
                                z10 = z4;
                                z = false;
                            }
                            break;
                        case 'e':
                            if (decodeCode < 64) {
                                z5 = z11;
                                if (z10 == z5) {
                                    sb.append((char) (decodeCode + 32));
                                } else {
                                    sb.append((char) (decodeCode + 32 + 128));
                                }
                            } else {
                                z4 = z10;
                                z5 = z11;
                                if (decodeCode >= CODE_FNC_3) {
                                    if (decodeCode != CODE_STOP) {
                                        z9 = false;
                                    }
                                    if (decodeCode != CODE_STOP) {
                                        switch (decodeCode) {
                                            case CODE_SHIFT /*{ENCODED_INT: 98}*/:
                                                z11 = z5;
                                                z10 = z4;
                                                z = true;
                                                c5 = 'd';
                                                break;
                                            case 100:
                                                z11 = z5;
                                                z10 = z4;
                                                z = false;
                                                c5 = 'd';
                                                break;
                                            case 101:
                                                if (z5 || !z4) {
                                                    if (z5) {
                                                    }
                                                    z11 = z5;
                                                    z = false;
                                                    z10 = true;
                                                    break;
                                                }
                                                z = false;
                                                z10 = false;
                                                z11 = true;
                                                break;
                                            case CODE_FNC_1 /*{ENCODED_INT: 102}*/:
                                                if (z6) {
                                                    if (sb.length() == 0) {
                                                        sb.append("]C1");
                                                    } else {
                                                        sb.append((char) 29);
                                                    }
                                                }
                                                z11 = z5;
                                                z10 = z4;
                                                z = false;
                                                break;
                                        }
                                    }
                                    z7 = true;
                                    z11 = z5;
                                    z10 = z4;
                                    z = false;
                                } else if (z4 == z5) {
                                    sb.append((char) (decodeCode - 64));
                                } else {
                                    sb.append((char) (decodeCode + 64));
                                }
                            }
                            z11 = z5;
                            z = false;
                            z10 = false;
                            break;
                        default:
                            z2 = z10;
                            z3 = z11;
                            z11 = z3;
                            z10 = z2;
                            z = false;
                            break;
                    }
                    if (z8) {
                        c5 = c5 == 'e' ? 'd' : 'e';
                    }
                    z8 = z;
                    i4 = i5;
                    c2 = 1;
                    r3 = 0;
                    i2 = 2;
                    c3 = 'c';
                    c4 = 6;
                    i5 = decodeCode;
                    i7 = i8;
                    i8 = i9;
                    break;
            }
        }
        int i10 = i8 - i7;
        int nextUnset = bitArray.getNextUnset(i8);
        if (!bitArray.isRange(nextUnset, Math.min(bitArray.getSize(), ((nextUnset - i7) / i2) + nextUnset), r3)) {
            throw NotFoundException.getNotFoundInstance();
        } else if ((i3 - (i6 * i4)) % CODE_START_A == i4) {
            int length = sb.length();
            if (length != 0) {
                if (length > 0 && z9) {
                    if (c5 == c3) {
                        sb.delete(length - 2, length);
                    } else {
                        sb.delete(length - 1, length);
                    }
                }
                float f = ((float) (findStartPattern[c2] + findStartPattern[r3 == true ? 1 : 0])) / 2.0f;
                float f2 = ((float) i7) + (((float) i10) / 2.0f);
                int size = arrayList.size();
                byte[] bArr = new byte[size];
                for (int i11 = 0; i11 < size; i11++) {
                    bArr[i11] = ((Byte) arrayList.get(i11)).byteValue();
                }
                String sb2 = sb.toString();
                ResultPoint[] resultPointArr = new ResultPoint[i2];
                float f3 = (float) i;
                resultPointArr[r3] = new ResultPoint(f, f3);
                resultPointArr[c2] = new ResultPoint(f2, f3);
                return new Result(sb2, bArr, resultPointArr, BarcodeFormat.CODE_128);
            }
            throw NotFoundException.getNotFoundInstance();
        } else {
            throw ChecksumException.getChecksumInstance();
        }
    }
}
